Version

Enum Version 

#[non_exhaustive]
pub enum Version { V1_1, V1_2, }
The YAML version that determines how plain scalars are resolved.

A document can declare its version with a %YAML directive. The version configured with DeserializerConfig::set_version applies to documents that do not declare a version.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


V1_1

YAML 1.1.

In addition to what YAML 1.2 supports, y, yes, on (and their negations) are booleans, integers can be written in binary (0b1010), octal (0777) and base 60 (1:30) and numbers can contain _ as digit separators. Unlike YAML 1.2, 0o777 is a string.



V1_2

YAML 1.2 with the core schema.